errors

package
v0.0.0-...-9218f0a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 7, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrParameterNotFound      = errors.New("parameter not found")
	ErrSecretNotFound         = errors.New("secret not found")
	ErrAccessDenied           = errors.New("access denied")
	ErrInvalidParameter       = errors.New("invalid parameter")
	ErrParameterAlreadyExists = errors.New("parameter already exists")
	ErrSecretAlreadyExists    = errors.New("secret already exists")
	ErrRateLimitExceeded      = errors.New("rate limit exceeded")
	ErrInvalidRequest         = errors.New("invalid request")
)

Common error types

Functions

func ExtractAWSErrorCode

func ExtractAWSErrorCode(err error) string

ExtractAWSErrorCode extracts the AWS error code from an error

func FormatError

func FormatError(err error) string

FormatError formats an error for user display

func IsAccessDeniedError

func IsAccessDeniedError(err error) bool

IsAccessDeniedError checks if the error is an access denied error

func IsAlreadyExistsError

func IsAlreadyExistsError(err error) bool

IsAlreadyExistsError checks if the error indicates a resource already exists

func IsNotFoundError

func IsNotFoundError(err error) bool

IsNotFoundError checks if the error is a not found error

func IsRateLimitError

func IsRateLimitError(err error) bool

IsRateLimitError checks if the error is due to rate limiting

func WrapAWSError

func WrapAWSError(err error, operation string, resource string) error

WrapAWSError wraps AWS errors with more context

Types

This section is empty.

Jump to