Documentation
¶
Index ¶
- Variables
- func ExtractAWSErrorCode(err error) string
- func FormatError(err error) string
- func IsAccessDeniedError(err error) bool
- func IsAlreadyExistsError(err error) bool
- func IsNotFoundError(err error) bool
- func IsRateLimitError(err error) bool
- func WrapAWSError(err error, operation string, resource string) error
Constants ¶
This section is empty.
Variables ¶
var ( ErrParameterNotFound = errors.New("parameter not found") ErrSecretNotFound = errors.New("secret not found") ErrAccessDenied = errors.New("access denied") ErrInvalidParameter = errors.New("invalid parameter") ErrParameterAlreadyExists = errors.New("parameter already exists") ErrSecretAlreadyExists = errors.New("secret already exists") ErrRateLimitExceeded = errors.New("rate limit exceeded") ErrInvalidRequest = errors.New("invalid request") )
Common error types
Functions ¶
func ExtractAWSErrorCode ¶
ExtractAWSErrorCode extracts the AWS error code from an error
func IsAccessDeniedError ¶
IsAccessDeniedError checks if the error is an access denied error
func IsAlreadyExistsError ¶
IsAlreadyExistsError checks if the error indicates a resource already exists
func IsNotFoundError ¶
IsNotFoundError checks if the error is a not found error
func IsRateLimitError ¶
IsRateLimitError checks if the error is due to rate limiting
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.